function [SNR, SNR2]= snr_spectrum_2snr(y, Fs, Fsig, Fmin, Fmax, Fmin2, Fmax2, zoom)
% [SNR, SNR2]= snr_spectrum_2snr(y, Fs, Fsig, Fmin, Fmax, Fmin2, Fmax2, zoom)
% 
% snr_spectrum plots the spectrum up to fs/2 of a signal
% (hann) and estimates SNR for a tone
% y     : Input vector
% Fs    : Sampling frequency
% Fsig  : Signal frequency for SNR estimnate
% Fmin  : Lower bandwidth frequency
% Fmax  : Upper bandwidth frequency
% Fmin2 : Second lower bandwidth frequency
% Fmax2 : Second upper bandwidth frequency
% zoom  : Create a second plot zoomed on the signal band if zoom=1
% 

     sbi=1;       % Main lobe spread
     colorize=1;  % Add colors for passband and signal
     N=length(y);
     
     
     % Power specter
     Y=fft(y);            % Take the FFT, use window and correct the signal power for window function error
    
     PSD=Y.*conj(Y);        % Compute the power density spectrum 
     %PSD=PSD./(sum(wnd.*conj(wnd)./N));  % Correct power for hann window coherent gain

     Nh=floor(N./2)+1;               % Calculate the number of unique points
     PSD=2*PSD(1:Nh);                % Throw away negative frequencies and compensate power
     PSD(1)./2;               % DC component is unique and should not be multiplied by two
     % Nyquist component is unique if the number of samples are even
     if ~rem(N,2)
         PSD(end)=PSD(end)./2;
     end    
     PSDdB=10.*log10(PSD);        % Generate PSD with a logaritmical axis
     PSDdB=PSDdB - max(PSDdB);    %Normalize to peak signal at 0dB
     % Frequency axis (note index 1 is always DC, and that index 2 to floor(end/2)+1 is always fs/2, 
     %                 regardless of even or odd number of samples)
     Fsh=Fs./2;
     ind_sig=round(Fsig*N/Fs+1);  % Add 1 to compensate for DC component
     ind_fmin=round(Fmin*N/Fs+1); % Add 1 to compensate for DC component
     ind_fmax=round(Fmax*N/Fs+1); % Add 1 to compensate for DC component
     ind_fmin2=round(Fmin2*N/Fs+1); % Add 1 to compensate for DC component
     ind_fmax2=round(Fmax2*N/Fs+1); % Add 1 to compensate for DC component
     fv=linspace(0,Fsh,Nh);

     % Estimate
     ps=sum(PSD(ind_sig-sbi:ind_sig+sbi));
     pns_est=(2.*sbi+1).*mean([PSD(ind_sig-sbi),PSD(ind_sig+sbi)]);
     pn=sum(PSD(ind_fmin:ind_sig-sbi-1))+sum(PSD(ind_sig+sbi+1:ind_fmax))+pns_est;
     pn2=sum(PSD(ind_fmin2:ind_sig-sbi-1))+sum(PSD(ind_sig+sbi+1:ind_fmax2))+pns_est;
     SNR=10.*log10(ps./pn);
     SNR2=10.*log10(ps./pn2);

     figure;
     if zoom == 1
         subplot(2,1,1);
         ftplot(PSDdB, fv, ind_fmin, ind_fmax, ind_sig, sbi, 'k');
         atmp=round([min(PSDdB(ind_fmin:ind_fmax)) max(PSDdB(ind_fmin:ind_fmax))]/10)*10+[-10 10];
         subplot(2,1,2);
         axis([fv(ind_fmin) fv(ind_fmax) atmp(1) atmp(2)]);
         ftplot(PSDdB, fv, ind_fmin, ind_fmax, ind_sig, sbi, 'b');
         atmp2=round([min(PSDdB(ind_fmin2:ind_fmax2)) max(PSDdB(ind_fmin2:ind_fmax2))]/10)*10+[-10 10];
         subplot(2,1,2);
         axis([fv(ind_fmin2) fv(ind_fmax2) atmp(1) atmp(2)]);
         ftplot(PSDdB, fv, ind_fmin2, ind_fmax2, ind_sig, sbi, 'g');
     else
         ftplot(PSDdB, fv, ind_fmin, ind_fmax, ind_fmin2, ind_fmax2, ind_sig, sbi, 'b');
         A=axis; x_pos=A(1)*10^(log10(A(2)/A(1))*0.1);
         text(x_pos,max(PSDdB)-15,sprintf('SNR(%2.1fkHz-%2.1fkHz) = %3.1f',Fmin/1000,Fmax/1000,SNR))
         text(x_pos,max(PSDdB)-22,sprintf('SNR2(%2.1fkHz-%2.1fkHz) = %3.1f',Fmin2/1000,Fmax2/1000,SNR2))
     end
end

function ftplot(pv, fv, ind_fmin, ind_fmax, ind_fmin2, ind_fmax2, ind_sig, sbi, color)

     grid on;
     semilogx(fv, pv, 'b');
     if strcmp(color, 'k')~=1
         hold on;
         % Mark passband
         semilogx(fv(ind_fmin:ind_fmax), pv(ind_fmin:ind_fmax),'k');
         % Mark second passband
         semilogx(fv(ind_fmin2:ind_fmax2), pv(ind_fmin2:ind_fmax2),'g');
         % Mark signal
         semilogx(fv(ind_sig-sbi:ind_sig+sbi), pv(ind_sig-sbi:ind_sig+sbi),'r');
         hold off;
     end

end
